.. _api:

API Documentation
=================

.. autoclass:: dask_sql.Context
   :members:
   :undoc-members:

.. autofunction:: dask_sql.run_server

.. autofunction:: dask_sql.cmd_loop

.. autofunction:: dask_sql.integrations.fugue.fsql
